import { Tree } from "../common/tree.js";
import { type ChildComponentInfo } from "./types.js";
export default class FloorTree extends Tree {
    /**
     * 'ancestorFloorId'를 조상으로 하는 새로운 빈 노드를 추가한다.
     * @param ancestorFloorId 조상 노드의 ID
     * @param newFloorId 새로운 노드의 ID
     * @returns 노드를 추가했는지 여부
     */
    appendNewEmptyNode(ancestorFloorId: string, newFloorId: string): boolean;
    /**
     * 'floorId'를 가진 노드의 이름을 초기화한다.
     * @param floorId 노드의 ID
     * @returns 노드를 초기화했는지 여부
     */
    resetNode(floorId: string): boolean;
    /**
     * 'floorId'를 가진 노드의 이름을 업데이트한다.
     * @param floorId 노드의 ID
     * @param childComponentInfo 자식 컴포넌트 정보
     * @param isDesignMode 디자인 모드 여부
     * @param debug 디버그 모드 여부
     * @returns 노드를 업데이트했는지 여부
     */
    updateNode(id: string, childComponentInfo: ChildComponentInfo, isDesignMode: boolean, debug?: boolean): boolean;
    /**
     * 'tree' 전체를 순회하면서 'oldId'를 'newId'로 변경한다.
     * @param oldId 변경할 기존 ID
     * @param newId 새로운 ID
     */
    replaceNodeId(oldId: string, newId: string): void;
    /**
     * 'tree' 노드 중에 'id'가 'floorId'인 노드를 찾아서 그 노드를 삭제한다.
     * @param id 삭제할 노드의 ID
     * @returns 노드를 삭제했는지 여부
     */
    removeNode(id: string): boolean;
    /**
     * Floor 트리 노드 중에 'id'가 'HTML DOM 트리'에서 존재하지 않는 노드들을 제거한다.
     * @param excludeIdMap 삭제에서 제외할 ID 맵
     */
    removeInvalidNodes(excludeIdMap: Map<string, string>): void;
}
